@@ -1,7 +1,7 @@
 /*
  *  Bubbling Load Monitoring Applet
- *  Copyright (C) 1999-2000 Johan Walles - d92-jwa@nada.kth.se
- *  http://www.nada.kth.se/~d92-jwa/code/#bubblemon
+ *  Copyright (C) 1999-2004 Johan Walles - walles@mailblocks.com
+ *  http://www.nongnu.org/bubblemon/
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -148,6 +148,7 @@ static void netload_receiveUpdates()
   receivingUpdates = 0;
 
   // Forget about all interfaces marked as shut down.
+  // Start with interfaces at the start of the list.
   while (interfaces != NULL && !interfaces->isAlive)
   {
     struct netload_interface *nextInterface = interfaces->next;
@@ -155,6 +156,7 @@ static void netload_receiveUpdates()
     free(interfaces);
     interfaces = nextInterface;
   }
+  // Clean out interfaces after the start of the list
   if (interfaces != NULL)
   {
     struct netload_interface *prev;
@@ -170,6 +172,11 @@ static void netload_receiveUpdates()
 	free(iter);
 	iter = prev->next;
       }
+      
+      if (iter == NULL)
+      {
+	break;
+      }
     }
   }
 }
